@@ -3,6 +3,7 @@ import tempfile
 
 from deployfish.config import get_config
 from deployfish.core.models import Manager, Model, Secret, Service
+from deployfish.exceptions import ObjectReadOnly
 
 
 # ----------------------------------------
@@ -35,7 +36,7 @@ class MySQLDatabaseManager(Manager):
         return databases
 
     def delete(self, obj):
-        raise self.ReadOnly('SSH Tunnel objects are read only.')
+        raise ObjectReadOnly('SSH Tunnel objects are read only.')
 
     def save(self, obj, root_user, root_password, ssh_target=None, verbose=False):
         return self.create(obj, root_user, root_password, ssh_target=ssh_target, verbose=verbose)
@@ -141,7 +142,7 @@ class MySQLDatabaseManager(Manager):
             else:
                 fd.close()
                 os.rename(file_path, filename + ".errors")
-                raise obj.OperationFailed('Failed to dump our MySQL db "{}" in {}:{}:  {}'.format(
+                raise obj.OperationFailed('Failed to dump our MySQL db "{}" in {}:{}: {}'.format(
                     obj.db,
                     obj.host,
                     obj.port,
@@ -165,7 +166,7 @@ class MySQLDatabaseManager(Manager):
             return output
         else:
             raise obj.OperationFailed(
-                'Failed to load "{}" into  database "{}" on {}:{}: {}'.format(
+                'Failed to load "{}" into database "{}" on {}:{}: {}'.format(
                     filepath,
                     obj.db,
                     obj.host,
@@ -374,7 +375,7 @@ class MySQLDatabase(Model):
         return self.objects.show_grants(self, ssh_target=ssh_target, verbose=verbose)
 
     def render_mysql_command(self, sql, user=None, password=None):
-        return '/usr/bin/mysql --host={host} --user={user} --password={password} --port={port} --execute="{sql}"'.format(  # noqa:E501
+        return '/usr/bin/mysql --host={host} --user={user} --password=\'{password}\' --port={port} --execute="{sql}"'.format(  # noqa:E501
             host=self.host,
             port=self.port,
             sql=sql,
@@ -405,7 +406,7 @@ class MySQLDatabase(Model):
         if not version:
             version = '5.6'
         sql = "ALTER DATABASE {} CHARACTER SET = {};".format(self.db, self.character_set)
-        sql = "ALTER DATABASE {} COLLATE = {};".format(self.db, self.collation)
+        sql += "ALTER DATABASE {} COLLATE = {};".format(self.db, self.collation)
         if version == '5.6':
             sql += "set password for '{}'@'%' = PASSWORD('{}');".format(self.user, self.password)
         else:
@@ -418,7 +419,7 @@ class MySQLDatabase(Model):
         if not version:
             version = '5.6'
         if version == '5.6':
-            cmd = "/usr/bin/mysqldump --host={host} --user={user} --password={password} --port={port} --opt {db}".format(  # noqa:E501
+            cmd = "/usr/bin/mysqldump --host={host} --user={user} --password='{password}' --port={port} --opt {db}".format(  # noqa:E501
                 host=self.host,
                 user=self.user,
                 password=self.password,
@@ -426,7 +427,7 @@ class MySQLDatabase(Model):
                 db=self.db
             )
         else:
-            cmd = "/usr/bin/mysqldump --no-tablespaces --host={host} --user={user} --password={password} --port={port} --opt {db}".format(  # noqa:E501
+            cmd = "/usr/bin/mysqldump --no-tablespaces --host={host} --user={user} --password='{password}' --port={port} --opt {db}".format(  # noqa:E501
                 host=self.host,
                 user=self.user,
                 password=self.password,
@@ -436,7 +437,7 @@ class MySQLDatabase(Model):
         return cmd
 
     def render_for_load(self):
-        cmd = "/usr/bin/mysql --host={} --user={} --password={} --port={} {} < {{filename}}; rm {{filename}}".format(
+        cmd = "/usr/bin/mysql --host={} --user={} --password='{}' --port={} {} < {{filename}} && rm {{filename}}".format(
             self.host,
             self.user,
             self.password,
